@@ -1,7 +1,7 @@
 package BaseInheritedGroups;
 use strict;
 use warnings;
-use base 'AccessorInstaller';
+use parent 'AccessorInstaller';
 
 __PACKAGE__->mk_inherited_accessors('basefield', 'undefined', ['refacc','reffield']);
 
